terraform {
  required_providers {
    proxmox = {
      source  = "Telmate/proxmox"
      version = "3.0.1-rc8"
    }
  }
}

provider "proxmox" {
  pm_api_url      = var.pm_api_url
  pm_user         = var.pm_user
  pm_password     = var.proxmox_password
  pm_tls_insecure = true
}

resource "proxmox_vm_qemu" "alpacas" {
  count       = var.alpaca_vm_count
  name        = "alpaca-${count.index + 1}"
  vmid        = 500 + count.index + 1
  target_node = var.target_node
  clone       = var.clone_template
  full_clone  = true
  agent       = 1

  sockets   = var.sockets
  cores     = var.cores
  memory    = var.memory
  scsihw    = "virtio-scsi-pci"
  boot      = "order=scsi0"
  ipconfig0 = "ip=dhcp"
  cicustom  = "user=local:snippets/cloud_init_alpaca_${count.index + 1}.yaml"

  disks {
    scsi {
      scsi0 {
        disk {
          size     = var.disk_size
          storage  = var.storage
          iothread = true
        }
      }
      scsi1 {
        cloudinit {
          storage = var.storage
        }
      }
    }
  }

  network {
    id     = 0
    model  = "virtio"
    bridge = var.bridge
  }
}


resource "proxmox_vm_qemu" "llamas" {
  count       = var.llama_vm_count
  name        = "llama-${count.index + 1}"
  vmid        = 600 + count.index + 1
  target_node = var.target_node
  clone       = var.clone_template
  full_clone  = true
  agent       = 1

  sockets   = var.sockets
  cores     = var.cores
  memory    = var.memory
  scsihw    = "virtio-scsi-pci"
  boot      = "order=scsi0"
  ipconfig0 = "ip=dhcp"
  cicustom  = "user=local:snippets/cloud_init_llama_${count.index + 1}.yaml"

  disks {
    scsi {
      scsi0 {
        disk {
          size     = var.disk_size
          storage  = var.storage
          iothread = true
        }
      }
      scsi1 {
        cloudinit {
          storage = var.storage
        }
      }
    }
  }

  network {
    id     = 0
    model  = "virtio"
    bridge = var.bridge
  }
}

